/*
 * ################################################################
 *
 *                    Fractal GCM Management API
 *
 * Copyright (C) 2009 INRIA, University of
 *                    Nice-Sophia Antipolis, ActiveEon
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: proactive@ow2.org
 *
 * Authors: INRIA, University of Nice-Sophia Antipolis, ActiveEon.
 *
 * ################################################################
 */
package org.etsi.uri.gcm.api.type;

import org.objectweb.fractal.api.type.InterfaceType;

/**
 * Component interface type. This interface extends the standard Fractal
 * {@link InterfaceType} interface to support the cardinality parameters.
 * 
 * @author INRIA, University of Nice-Sophia Antipolis, ActiveEon
 * @see InterfaceType
 */
public interface GCMInterfaceType extends InterfaceType {

    /**
     * Returns the cardinality of component interfaces of this type. The
     * possible cardinalities are:
     * <ul>
     * <li> {@link GCMTypeFactory#SINGLETON_CARDINALITY singleton}</li>
     * <li> {@link GCMTypeFactory#COLLECTION_CARDINALITY collection}</li>
     * <li> {@link GCMTypeFactory#MULTICAST_CARDINALITY multicast}</li>
     * <li> {@link GCMTypeFactory#GATHERCAST_CARDINALITY gathercast}</li>
     * </ul>
     * 
     * @return Cardinality of component interfaces of this type.
     */
    public String getGCMCardinality();

    /**
     * Checks whether component interfaces of this type have a singleton
     * cardinality.
     * 
     * @return <tt>true</tt> if component interfaces of this type have a
     *         singleton cardinality, <tt>false</tt> otherwise.
     * @see GCMTypeFactory#SINGLETON_CARDINALITY
     */
    public boolean isGCMSingletonItf();

    /**
     * Checks whether component interfaces of this type have a collection
     * cardinality.
     * 
     * @return <tt>true</tt> if component interfaces of this type have a
     *         collection cardinality, <tt>false</tt> otherwise.
     * @see GCMTypeFactory#COLLECTION_CARDINALITY
     */
    public boolean isGCMCollectionItf();

    /**
     * Checks whether component interfaces of this type have a multicast
     * cardinality.
     * 
     * @return <tt>true</tt> if component interfaces of this type have a
     *         multicast cardinality, <tt>false</tt> otherwise.
     * @see GCMTypeFactory#MULTICAST_CARDINALITY
     */
    public boolean isGCMMulticastItf();

    /**
     * Checks whether component interfaces of this type have a gathercast
     * cardinality.
     * 
     * @return <tt>true</tt> if component interfaces of this type have a
     *         gathercast cardinality, <tt>false</tt> otherwise.
     * @see GCMTypeFactory#GATHERCAST_CARDINALITY
     */
    public boolean isGCMGathercastItf();
}
