/*
 * ################################################################
 *
 *                    Fractal GCM Management API
 *
 * Copyright (C) 2009 INRIA, University of
 *                    Nice-Sophia Antipolis, ActiveEon
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: proactive@ow2.org
 *
 * Authors: INRIA, University of Nice-Sophia Antipolis, ActiveEon.
 *
 * ################################################################
 */
package org.etsi.uri.gcm.api.type;

import org.objectweb.fractal.api.factory.InstantiationException;
import org.objectweb.fractal.api.type.InterfaceType;
import org.objectweb.fractal.api.type.TypeFactory;

/**
 * Component interface to create component and interface type objects. This
 * interface extends the standard Fractal {@link TypeFactory} interface to
 * support the cardinality parameter.
 * 
 * @author INRIA, University of Nice-Sophia Antipolis, ActiveEon
 * @see TypeFactory
 */
public interface GCMTypeFactory extends TypeFactory {

    /**
     * The <tt>cardinality</tt> value to be used in {@link #createGCMItfType} to
     * create a singleton interface type.
     */
    public static final String SINGLETON_CARDINALITY = "singleton";

    /**
     * The <tt>cardinality</tt> value to be used in {@link #createGCMItfType} to
     * create a collection interface type.
     */
    public static final String COLLECTION_CARDINALITY = "collection";

    /**
     * The <tt>cardinality</tt> value to be used in {@link #createGCMItfType} to
     * create a multicast interface type.
     */
    public static final String MULTICAST_CARDINALITY = "multicast";

    /**
     * The <tt>cardinality</tt> value to be used in {@link #createGCMItfType} to
     * create a gathercast interface type.
     */
    public static final String GATHERCAST_CARDINALITY = "gathercast";

    /**
     * Creates an interface type with a particular cardinality.
     * 
     * @param name
     *            Name of component interfaces of this type (see
     *            {@link InterfaceType#getFcItfName getFcItfName}).
     * @param signature
     *            Signatures of the methods of component interfaces of this
     *            type. In Java this "signature" is the fully qualified name of
     *            a Java interface corresponding to these method signatures.
     * @param isClient
     *            <tt>true</tt> if component interfaces of this type are client
     *            interfaces, <tt>false</tt> otherwise.
     * @param isOptional
     *            <tt>true</tt> if component interfaces of this type are
     *            optional interfaces, <tt>false</tt> otherwise.
     * @param cardinality
     *            Cardinality of component interfaces of this type (see
     *            {@link GCMInterfaceType#getGCMCardinality()} for a description
     *            of cardinalities).
     * @return Interface type initialized with the given values.
     * @throws InstantiationException
     *             If the interface type cannot be created.
     */
    public InterfaceType createGCMItfType(String name, String signature,
                                          boolean isClient, boolean isOptional,
                                          String cardinality)
            throws InstantiationException;
}
